@@ -60,6 +60,11 @@ const command_definitions = Dict(
     raw"\overline" => (TeXExpr(:overline), 1),
     raw"\{" => (TeXExpr(:delimiter, '{'), 0),
     raw"\}" => (TeXExpr(:delimiter, '}'), 0),
+    raw"\_" => (TeXExpr(:symbol, '_'), 0),
+    raw"\%" => (TeXExpr(:symbol, '%'), 0),
+    raw"\$" => (TeXExpr(:symbol, '$'), 0),
+    raw"\#" => (TeXExpr(:symbol, '#'), 0),
+    raw"\&" => (TeXExpr(:symbol, '&'), 0),
     raw"\fontfamily" => (TeXExpr(:fontfamily), 1),
     raw"\glyph" => (TeXExpr(:glyph), 2),
     raw"\unicode" => (TeXExpr(:unicode), 2),
